@@ -42,7 +42,7 @@ sub import {
   foreach my $key (@list) {
     my ($src, $empty, @args) = _parse($target, $key);
     load($src);
-    return if $empty;
+    next if $empty;
     if (my $import = $src->can('import')) {
       Evo::Lib::Bare::inject(
         package  => $target,
@@ -60,7 +60,7 @@ sub import {
 
 1;
 
-our $VERSION = '0.0209';    # VERSION
+# VERSION
 
 # ABSTRACT: Evo - the next generation development framework
 
@@ -76,7 +76,7 @@ Evo - Evo - the next generation development framework
 
 =head1 VERSION
 
-version 0.0209
+version 0.0210
 
 =head1 DESCRIPTION
 
