@@ -1,8 +1,15 @@
 package Evo::Class;
-use Evo '-Export *, -import, import_all:import';
-use Evo '-Class::Hash ()';
+use Evo '::Gen::Hash GEN; -Class::Meta; -Class::Common meta_of';
+use Evo '-Export *, -import';
+
+export_proxy '::Common', '*';
+
+sub import ($me, @args) {
+  my $caller = caller;
+  meta_of($caller) || meta_of($caller, Evo::Class::Meta::new(class => $caller, gen => GEN));
+  export_install_in($caller, $me, @args ? @args : '*');
+}
 
-export_proxy('Evo::Class::Hash', '*');
 
 1;
 
@@ -18,7 +25,7 @@ Evo::Class
 
 =head1 VERSION
 
-version 0.0209
+version 0.0210
 
 =head1 DESCRIPTION
 
@@ -50,11 +57,12 @@ Also traditional OO programming suffers the fragile base class problems (use Goo
   {
 
     package My::Human;
-    use Evo '-Class *';
+    use Evo -Class, -Loaded;
 
     has 'name' => 'unnamed';
     has 'gender', is => 'ro', required => 1;
     has age => check => sub($v) { $v >= 18 };
+    sub greet($self) : Public { say "I'm " . $self->name }
   }
 
   my $alex = My::Human::new(gender => 'male');
@@ -66,12 +74,36 @@ Also traditional OO programming suffers the fragile base class problems (use Goo
   $alex->name('Alex')->age(18);
   say $alex->name, ': ', $alex->age;
 
-  # will die, gender is required
-  My::Human::new();
+  # method
+  $alex->greet;
 
-  # will die, age must be >= 18
-  My::Human::new(age => 17, gender => 'male');
-  My::Human::new()->age(17, gender => 'male');
+  ## ------------ protecting you from errors, uncomment to test
+  ## will die, gender is required
+  #My::Human::new();
+
+  ## will die, age must be >= 18
+  #My::Human::new(age => 17, gender => 'male');
+  #My::Human::new()->age(17, gender => 'male');
+
+  # --------- code reuse
+  {
+
+    package My::Developer;
+    use Evo -Class;
+    with 'My::Human'; # extends 'My::Human'; implements 'My::Human';
+
+    has lang => 'Perl';
+
+    sub show($self) : Public {
+      $self->greet();
+      say "I like ", $self->lang;
+    }
+
+
+  }
+
+  my $dev = My::Developer::new(gender => 'male');
+  $dev->show;
 
 =head1 Usage
 
@@ -134,9 +166,10 @@ Can be 'rw' or 'ro'; Unlike Perl6 is 'rw' by default
 
 Attribute will be filled with this value if isn't provided to the C<new> constructor You can't use references, but you can provide a coderef instead of value, in this case return value of an invocation of this function will be used.
 
-  # pay attention, no argument passed here
-  has ref => sub() { {} };
-  has foo => default => sub() { [] };
+  has ref => sub(%build_args) { {} };
+  has foo => default => sub(%build_args) { [] };
+
+This is a good way to init some attribute that should always exists. Arguments, passed to C<new> or C<init>  will be passed to the function without object itself (because there are no object yet). If you're expecting another behaviour, check L</lazy>
 
 =head4 lazy
 
@@ -173,26 +206,65 @@ You can also return C<(0, "CustomError")> to provide more expressive explanation
   $foo->big(9);    # will die
   my $bar = My::Foo::new(big => 9);    # will die
 
-=head1 Code reuse
+=head1 CODE REUSE
 
-Instead of OO inheritance, wich suffers from fragile base class problem, C<Evo::Class> provides L<Evo::Role>. This is a perfect choice for code reuse because of it's safety and flexibility. Look at L<Evo::Role> for more information
+Method should be marked with C<:Public> if you want to reuse them; Attributes are all public;
+
+=head2 Overriding
+
+Evo protects you from method clashing. But if you want to override method or fix clashing, use L</has_overriden> function or C<:Override> attribute
+
+    package My::Peter;
+    use Evo -Class;
+    with 'My::Human';
+
+    has_overriden name => 'peter';
+    sub greet : Overriden { }
+
+This differs from traditional OO style. With compoment programming, you should reuse code via L<Evo::Class::Role> or just organize classes with independed pieces of code like "mixing". So, try to override less
+
+=head2 extends
+
+Extends classes or roles
+
+=head2 implements
+
+Check if all required methods are implemented. Like interfaces
 
 =head2 with
 
-Load role and install all methods and attributes to the Evo object. Supports L<Evo/"shortcuts">
+This does "extend + check implementation". Consider this example:
 
-    package Person;
-    use Evo '-Class *';
+  package main;
+  use Evo;
 
-    with ':LoudHuman', ':Human';
+  {
 
-Circular requirements can be solved by requiring roles in the single C<with>. See L<Evo::Role/"requires">
+    package My::Role::Happy;
+    use Evo -Class, -Loaded;
 
-=head2 overrides
+    requires 'name';
 
-  override qw(foo bar);
+    sub greet($self) : Public {
+      say "My name is ", $self->name, " and I'm happy!";
+    }
 
-Mark names as overriden. Use it before L</"with">. You can also use C<Override> attribute, wich is preferred. See L<Evo::Role/"Overriding methods">
+    package My::Class;
+    use Evo -Class;
+
+    has name => 'alex';
+
+    #extends 'My::Role::Happy';
+    #implements 'My::Role::Happy';
+    with 'My::Role::Happy';
+
+  }
+
+  My::Class::new()->greet();
+
+C<My::Role::Happy> requires C<name> in derivered class. We could install shared code with C<extends> and then check implemantation with C<implements>. Or just use C<with> wich does both.
+
+You may want to use C<extends> and C<implements> separately to resolve circular requirements, for example
 
 =head1 CODE ATTRIBUTES
 
