@@ -14,11 +14,11 @@ my $GEN = {map { ($_, *{"gen_$_"}{CODE}) } qw(gs gsch gs_value gsch_value gs_cod
 
 sub GEN : Export {$GEN}
 
-sub gen_new ($_class, $opts) {
+sub gen_new ($class, $opts) {
 
   sub {
-    my $class = @_ % 2 ? $_class : shift;
-    my ($obj, %attrs) = @_;
+    my $obj   = shift;
+    my %attrs = @_;
     exists $attrs{$_} or croak qq#Attribute "$_" is required# for $opts->{required}->@*;
 
     foreach my $k (keys %attrs) {
@@ -28,8 +28,8 @@ sub gen_new ($_class, $opts) {
         croak_bad_value($attrs{$k}, $k, $err) unless $ok;
       }
     }
-    exists $attrs{$_} or $attrs{$_} = $opts->{dv}{$_}      for keys $opts->{dv}->%*;
-    exists $attrs{$_} or $attrs{$_} = $opts->{dfn}{$_}->() for keys $opts->{dfn}->%*;
+    exists $attrs{$_} or $attrs{$_} = $opts->{dv}{$_}        for keys $opts->{dv}->%*;
+    exists $attrs{$_} or $attrs{$_} = $opts->{dfn}{$_}->(@_) for keys $opts->{dfn}->%*;
 
     $DATA{$obj} = \%attrs;
     bless $obj, $class;
@@ -106,7 +106,7 @@ Evo::Class::Gen::HUF
 
 =head1 VERSION
 
-version 0.0209
+version 0.0210
 
 =head1 AUTHOR
 
