@@ -23,8 +23,8 @@ sub gen_new ($_class, $opts) {
         croak_bad_value($attrs{$k}, $k, $err) unless $ok;
       }
     }
-    exists $attrs{$_} or $attrs{$_} = $opts->{dv}{$_}      for keys $opts->{dv}->%*;
-    exists $attrs{$_} or $attrs{$_} = $opts->{dfn}{$_}->() for keys $opts->{dfn}->%*;
+    exists $attrs{$_} or $attrs{$_} = $opts->{dv}{$_}        for keys $opts->{dv}->%*;
+    exists $attrs{$_} or $attrs{$_} = $opts->{dfn}{$_}->(@_) for keys $opts->{dfn}->%*;
 
     bless \%attrs, $class;
   };
@@ -100,7 +100,7 @@ Evo::Class::Gen::Hash
 
 =head1 VERSION
 
-version 0.0209
+version 0.0210
 
 =head1 AUTHOR
 
