@@ -1,36 +1,34 @@
 package Evo::Ee;
-use Evo '-Role *';
-use Carp 'croak';
-use List::Util 'first';
+use Evo -Class, 'Carp croak; List::Util first';
 
 requires 'ee_events';
 
 # [name, cb]
 has ee_data => sub { {q => [], cur => undef} };
 
-sub ee_check ($self, $name) : Role {
+sub ee_check ($self, $name) : Public {
   croak qq{Not recognized event "$name"} unless first { $_ eq $name } $self->ee_events;
   $self;
 }
 
-sub on ($self, $name, $fn) : Role {
+sub on ($self, $name, $fn) : Public {
   push $self->ee_check($name)->ee_data->{q}->@*, [$name, $fn];
   $self;
 }
 
-sub ee_add ($self, $name, $fn) : Role {
+sub ee_add ($self, $name, $fn) : Public {
   push $self->ee_check($name)->ee_data->{q}->@*, my $id = [$name, $fn];
   $id;
 }
 
-sub ee_remove ($self, $id) : Role {
+sub ee_remove ($self, $id) : Public {
   my $data = $self->ee_data->{q};
   defined(my $index = first { $data->[$_] == $id } 0 .. $#$data) or croak "$id isn't a listener";
   splice $data->@*, $index, 1;
   $self;
 }
 
-sub ee_remove_current($self) : Role {
+sub ee_remove_current($self) : Public {
   my ($q, $cur) = @{$self->ee_data}{qw(q cur)};
   defined(my $index = first { $q->[$_] == $cur } 0 .. $#$q) or croak "Not in the event";
   splice $q->@*, $index, 1;
@@ -38,14 +36,14 @@ sub ee_remove_current($self) : Role {
 }
 
 
-sub emit ($self, $name, @args) : Role {
+sub emit ($self, $name, @args) : Public {
   my $data = $self->ee_data;
   do { local $data->{cur} = $_; $_->[1]->($self, @args) }
     for grep { $_->[0] eq $name } $self->ee_data->{q}->@*;
   $self;
 }
 
-sub ee_listeners ($self, $name) : Role {
+sub ee_listeners ($self, $name) : Public {
   grep { $_->[0] eq $name } $self->ee_data->{q}->@*;
 }
 
@@ -63,7 +61,7 @@ Evo::Ee
 
 =head1 VERSION
 
-version 0.0209
+version 0.0210
 
 =head1 DESCRIPTION
 
