@@ -1,7 +1,5 @@
 package Evo::Loop::Class;
-use Evo '-Class *', '-Lib steady_time';
-use List::Util 'first';
-use Time::HiRes 'usleep';
+use Evo -Class, '-Lib steady_time; List::Util first; Time::HiRes usleep';
 
 has is_running => 0;
 has tick_time => \&steady_time, is => 'rw';
@@ -63,7 +61,7 @@ Evo::Loop::Class
 
 =head1 VERSION
 
-version 0.0209
+version 0.0210
 
 =head1 AUTHOR
 
