@@ -1,14 +1,14 @@
 package Evo::Loop::Role::Postpone;
-use Evo '-Role *';
+use Evo '-Class::Role *';
 
 requires qw(zone_cb);
 
 has data_postpone => default => sub { [] };
 
-sub postpone_count($self) : Role { $self->data_postpone->@* }
-sub postpone ($self, $fn) : Role { push $self->data_postpone->@*, $self->zone_cb($fn); }
+sub postpone_count($self) : Public { $self->data_postpone->@* }
+sub postpone ($self, $fn) : Public { push $self->data_postpone->@*, $self->zone_cb($fn); }
 
-sub postpone_process($self) : Role {
+sub postpone_process($self) : Public {
   my $postpone = $self->data_postpone;
   shift(@$postpone)->() while @$postpone;
 }
@@ -27,7 +27,7 @@ Evo::Loop::Role::Postpone
 
 =head1 VERSION
 
-version 0.0209
+version 0.0210
 
 =head1 AUTHOR
 
