@@ -1,6 +1,5 @@
 package Evo::Loop::Role::Timer;
-use Evo '-Role *; Carp croak';
-use List::Util 'first';
+use Evo -Class::Role, 'Carp croak; List::Util first';
 
 requires qw(zone_cb tick_time);
 
@@ -10,9 +9,9 @@ has timer_queue => sub { [] };
 # [time, zcb]
 # alwais check timer_count before timer_process or calculate_timeout
 
-sub timer_count : Role { scalar $_[0]->timer_queue->@* }
+sub timer_count : Public { scalar $_[0]->timer_queue->@* }
 
-sub timer : Role {
+sub timer : Public {
   croak "Not enought arguments" if @_ < 3;
   my ($self, $after, $cb, $period) = (shift, shift, pop, shift);
   croak "Negative period!" if $period && $period < 0;
@@ -23,14 +22,14 @@ sub timer : Role {
   $slot;
 }
 
-sub timer_remove ($self, $ref) : Role {
+sub timer_remove ($self, $ref) : Public {
   my $que = $self->timer_queue;
 
   defined(my $index = first { $que->[$_] == $ref } 0 .. $#$que) or return;
   splice $que->@*, $index, 1;
 }
 
-sub timer_sort_if_needed($self) : Role {
+sub timer_sort_if_needed($self) : Public {
   return unless $self->timer_need_sort;
   my $timer_queue = $self->timer_queue;
   $timer_queue->@* = sort { $a->[0] <=> $b->[0] } $timer_queue->@*;
@@ -40,7 +39,7 @@ sub timer_sort_if_needed($self) : Role {
 # queue is a list of unsorted timers. Queue becomes sorted at the beginning.
 # Adding timer makes queue unsorted again.
 # because timers are sorted, process till first future timer
-sub timer_process($self) : Role {
+sub timer_process($self) : Public {
   $self->timer_sort_if_needed();
   my $time        = $self->tick_time;
   my $timer_queue = $self->timer_queue;
@@ -59,7 +58,7 @@ sub timer_process($self) : Role {
 # calculates a timeout the app can sleep without missing timer
 # assumes that have at least one timer. Calls sort_if_needed
 # returns ms (1s/1000), >=0
-sub timer_calculate_timeout($self) : Role {
+sub timer_calculate_timeout($self) : Public {
   $self->timer_sort_if_needed();
   my $timeout = ($self->timer_queue->[0][0] - $self->tick_time);
   return $timeout > 0 ? $timeout : 0;
@@ -79,7 +78,7 @@ Evo::Loop::Role::Timer
 
 =head1 VERSION
 
-version 0.0209
+version 0.0210
 
 =head1 AUTHOR
 
