@@ -1,18 +1,17 @@
 package Evo::Loop::Role::Zone;
-use Evo '-Role *; -Lib *';
-use Carp 'croak';
+use Evo -Class::Role, '-Lib *; Carp croak';
 
 has zone_data => sub { {middleware => []} };
 
 # calls callback with passed ws, and combines prev + passed for wcb
-sub zone : Role {
+sub zone : Public {
   my ($self, $fn) = (shift, pop);
   my $data = $self->zone_data;
   local $data->{middleware} = [$data->{middleware}->@*];
   $fn->();
 }
 
-sub zone_cb ($self, $cb) : Role {
+sub zone_cb ($self, $cb) : Public {
   my $data = $self->zone_data;
   my @ws   = $data->{middleware}->@*;
 
@@ -22,7 +21,7 @@ sub zone_cb ($self, $cb) : Role {
   };
 }
 
-sub zone_middleware ($self, @mw) : Role {
+sub zone_middleware ($self, @mw) : Public {
   my $mw = $self->zone_data->{middleware};
   push $mw->@*, @mw if @mw;
   $mw;
@@ -43,7 +42,7 @@ Evo::Loop::Role::Zone
 
 =head1 VERSION
 
-version 0.0209
+version 0.0210
 
 =head1 AUTHOR
 
