@@ -1,5 +1,5 @@
 package Evo::Net::Srv::Role;
-use Evo '-Role *; -Loop *; -Io *; -Lib::Net *; Carp croak';
+use Evo '-Class::Role *; -Loop *; -Io *; -Lib::Net *; Carp croak';
 use Errno qw( EAGAIN EWOULDBLOCK );
 use Socket qw( AF_INET AF_INET6 SOL_SOCKET SOMAXCONN);
 use Scalar::Util 'weaken';
@@ -10,38 +10,38 @@ has srv_acceptors => sub { [] };
 
 has _srv_conn_data => sub { fieldhash my %hash; \%hash }, is => 'ro';
 
-sub srv_connectionss ($s, @conns) : Role {
+sub srv_connectionss ($s, @conns) : Public {
   my $data = $s->_srv_conn_data;
   return map { id_2obj $_} keys %$data unless @conns;
   $data->{$_}++ for @conns;
 }
 
-sub srv_handle_error ($self, $sock, $err) : Role { $self->srv_remove_socket($sock); }
-sub srv_handle_accept ($self, $sock) : Role {$sock}
+sub srv_handle_error ($self, $sock, $err) : Public { $self->srv_remove_socket($sock); }
+sub srv_handle_accept ($self, $sock) : Public {$sock}
 
-sub srv_start_watching ($self, $sock) : Role {
+sub srv_start_watching ($self, $sock) : Public {
   loop_io_in $sock, sub { $self->srv_accept($sock) };
   loop_io_error $sock, sub { $self->srv_handle_error($sock, "Unknown") };
 }
-sub srv_stop_watching ($self, $sock) : Role { loop_io_remove_all $sock; }
+sub srv_stop_watching ($self, $sock) : Public { loop_io_remove_all $sock; }
 
-sub srv_stop($self) : Role {
+sub srv_stop($self) : Public {
   croak "already stopped" unless $self->srv_is_running;
   $self->srv_is_running(0);
   $self->srv_stop_watching($_) for $self->srv_acceptors->@*;
 }
 
-sub srv_start($self) : Role {
+sub srv_start($self) : Public {
   croak "already running" if $self->srv_is_running;
   $self->srv_is_running(1);
   $self->srv_start_watching($_) for $self->srv_acceptors->@*;
 }
 
-sub srv_remove_socket ($self, $sock) : Role {
+sub srv_remove_socket ($self, $sock) : Public {
   $self->srv_acceptors([grep { $_ != $sock } $self->srv_acceptors->@*]);
 }
 
-sub srv_accept ($self, $sock) : Role {
+sub srv_accept ($self, $sock) : Public {
   my $child;
   while ($child = $sock->io_accept()) {
 
@@ -54,7 +54,7 @@ sub srv_accept ($self, $sock) : Role {
 }
 
 
-sub srv_listen ($self, %opts) : Role {
+sub srv_listen ($self, %opts) : Public {
   my @conn_keys = qw(port ip backlog reuseport);
   my %conn      = %opts{@conn_keys};
   delete $opts{$_} for @conn_keys;
@@ -84,7 +84,7 @@ Evo::Net::Srv::Role
 
 =head1 VERSION
 
-version 0.0209
+version 0.0210
 
 =head1
 
