@@ -1,7 +1,9 @@
 package Test::Evo::Helpers;
 
+
 use Evo '-Export *';
-use Evo '-Class::Meta; Socket :all; -Role::Exporter; -Io *; -Lib::Net *; Socket AF_INET6';
+
+use Evo '-Class::Meta; Socket :all; -Io *; -Lib::Net *; Socket AF_INET6';
 
 use constant CAN_BIND6 => eval {
   my ($saddr, $family) = net_gen_saddr_family('::1', undef);
@@ -22,7 +24,24 @@ sub comp_meta : Export {
     };
   }
 
-  Evo::Class::Meta::new(gen => \%gen, rex => Evo::Role::Exporter::new());
+  Evo::Class::Meta::new(gen => \%gen, rex => Evo::Role::Class::new());
+}
+
+sub dummy_meta : Export {
+  my $class = shift || 'My::Dummy';
+  my %gen;
+  foreach my $what (qw(gs gsch)) {
+    $gen{$what} = sub {
+      sub {$what}
+    };
+  }
+
+  $gen{new} = sub {
+    my $str = join ',', @_;
+    sub {$str}
+  };
+
+  Evo::Class::Meta::new(gen => \%gen, class => $class);
 }
 
 1;
@@ -39,7 +58,7 @@ Test::Evo::Helpers
 
 =head1 VERSION
 
-version 0.0209
+version 0.0210
 
 =head1 AUTHOR
 
